// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIokgYJKoZIhvcNAQcCoIIogzCCKH8CAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg30MIIGcjCCBFqgAwIBAgITMwAAAwacnF0l4xCqRwAA
// SIG // AAADBjANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1OVoX
// SIG // DTIzMDgwMzIwMjM1OVowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAK2u4fiSc3xWuygObXzuz5xw
// SIG // CEFOymdqqry0VzGbnAs4XM+27kC/sqp5l+sishRCL/bI
// SIG // SgdT9xOOQeAY+k1qP2eeu68NqkijG+l+m+3uB87/V4Ku
// SIG // gn23MYq4aaIecepcd5GNVkFENyOEmdIgxLGITe1kxP50
// SIG // cgOdCOQBPFlPm8T/rNvMwgxaKrlka50CvDJcb1Qps+ar
// SIG // aLdt8oYfove05BRY5cEN/gcdhnX4uACBs+MV1vj6TNAs
// SIG // usFQSlKZqo9VzvcOTVnubtWf+P+HyLDYYfdTz1/Be+qo
// SIG // GdOUURn6FFAQsbsRCkd1cKFd7PxFwhJh8+BnFnDnltKG
// SIG // rwO6bE58l3MXDN0VhTwi7R00WwD3DtfH7G/F5P2g1Lx6
// SIG // YTdJFanBF+8P/Pq5bgyE1Gt1g3oURS+92fCQEXIrHO8R
// SIG // 7s6IyRxGOqgqSZHGVuPVxVjYcYG9zRuCghyh9LzkTSB+
// SIG // c+X246++4yZa7hQ3cxxu2IYqOekIsIIP5iYVdZl4hlHf
// SIG // r8qT6wIDAQABo4IBgjCCAX4wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFJeTbNuZ
// SIG // ijAuRAcaJm8xGG8hhSfHMFQGA1UdEQRNMEukSTBHMS0w
// SIG // KwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRp
// SIG // b25zIExpbWl0ZWQxFjAUBgNVBAUTDTQ2NDIyMys0NzIy
// SIG // MzgwHwYDVR0jBBgwFoAUSG5k5VAF04KqFzc3IrVtqMp1
// SIG // ApUwVAYDVR0fBE0wSzBJoEegRYZDaHR0cDovL3d3dy5t
// SIG // aWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNybDBhBggrBgEFBQcB
// SIG // AQRVMFMwUQYIKwYBBQUHMAKGRWh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNydDAMBgNVHRMBAf8E
// SIG // AjAAMA0GCSqGSIb3DQEBDAUAA4ICAQBYP6acCgdQBVM4
// SIG // Qe1cJ2sUAcvNHG3W9uMACu/bMjoZnCEixqFwYcHjt66p
// SIG // Wt82FVbFg5/DXuKpDX9ItoofLaSJdjSYJgtfNj3QFagh
// SIG // T0mzcC3te96VqBn5vmPXoKpAB1iWPyFH4Xjk3y1QCV4P
// SIG // xF4ZdJV54ajz+rE3FEz5wwk2ahCyRl1ZpeQYM7MAP0bk
// SIG // 3umGR7wFg97vqq9/V3KwFRT5KuQA4Sm4ooPoPu5sPMSV
// SIG // 0cxGUHcf0+ji7Mi347bqrc/pfEZPxjFzRn4sbpTAP84Y
// SIG // jQuIi4HmwB870aI16aMepkNhprw6fKbnHUFjKANyEb1g
// SIG // 2/iCNcjQaIf1BiWbS4kFRkWhI/kbUlBIKK/j5loupwH1
// SIG // 8sWKGJY0bhSKcZ7pkQUp+B6jFknGng+fIe1VknJ/9n94
// SIG // xsb8ct2mqtciXdqgZ5f/E4eoKBS15lJ1Z9AFnIKhmqCc
// SIG // KhERhlFfeXGlcy+CBtR96dPpYzUrQFDeFflh6cW+V+VA
// SIG // WN/5tXQDXgTJpo0dY794AarprlQjARLkt9T+PLQCMt8g
// SIG // XrVvIvJ/14SVkA1t17JaNHSCvHqjI6ij4AJAzxA6XRDE
// SIG // gySHfdDHzk9Aj1pntn+9zMdBMfsCyMB6aBqVVmOKaJ1d
// SIG // YEyC1d6WvU+SWbn123WSyzsHHswrxTGuI3OhgO6hgbCu
// SIG // DMMmRx5k8zCCB3owggVioAMCAQICCmEOkNIAAAAAAAMw
// SIG // DQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRp
// SIG // ZmljYXRlIEF1dGhvcml0eSAyMDExMB4XDTExMDcwODIw
// SIG // NTkwOVoXDTI2MDcwODIxMDkwOVowfjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEoMCYGA1UEAxMfTWljcm9zb2Z0IENvZGUg
// SIG // U2lnbmluZyBQQ0EgMjAxMTCCAiIwDQYJKoZIhvcNAQEB
// SIG // BQADggIPADCCAgoCggIBAKvw+nIQHC6t2G6qghBNNLry
// SIG // tlghn0IbKmvpWlCquAY4GgRJun/DDB7dN2vGEtgL8DjC
// SIG // mQawyDnVARQxQtOJDXlkh36UYCRsr55JnOloXtLfm1Oy
// SIG // CizDr9mpK656Ca/XllnKYBoF6WZ26DJSJhIv56sIUM+z
// SIG // RLdd2MQuA3WraPPLbfM6XKEW9Ea64DhkrG5kNXimoGMP
// SIG // LdNAk/jj3gcN1Vx5pUkp5w2+oBN3vpQ97/vjK1oQH01W
// SIG // KKJ6cuASOrdJXtjt7UORg9l7snuGG9k+sYxd6IlPhBry
// SIG // oS9Z5JA7La4zWMW3Pv4y07MDPbGyr5I4ftKdgCz1TlaR
// SIG // ITUlwzluZH9TupwPrRkjhMv0ugOGjfdf8NBSv4yUh7zA
// SIG // IXQlXxgotswnKDglmDlKNs98sZKuHCOnqWbsYR9q4ShJ
// SIG // nV+I4iVd0yFLPlLEtVc/JAPw0XpbL9Uj43BdD1FGd7P4
// SIG // AOG8rAKCX9vAFbO9G9RVS+c5oQ/pI0m8GLhEfEXkwcNy
// SIG // euBy5yTfv0aZxe/CHFfbg43sTUkwp6uO3+xbn6/83bBm
// SIG // 4sGXgXvt1u1L50kppxMopqd9Z4DmimJ4X7IvhNdXnFy/
// SIG // dygo8e1twyiPLI9AN0/B4YVEicQJTMXUpUMvdJX3bvh4
// SIG // IFgsE11glZo+TzOE2rCIF96eTvSWsLxGoGyY0uDWiIwL
// SIG // AgMBAAGjggHtMIIB6TAQBgkrBgEEAYI3FQEEAwIBADAd
// SIG // BgNVHQ4EFgQUSG5k5VAF04KqFzc3IrVtqMp1ApUwGQYJ
// SIG // KwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQD
// SIG // AgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU
// SIG // ci06AjGQQ7kUBU7h6qfHMdEjiTQwWgYDVR0fBFMwUTBP
// SIG // oE2gS4ZJaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0MjAxMV8y
// SIG // MDExXzAzXzIyLmNybDBeBggrBgEFBQcBAQRSMFAwTgYI
// SIG // KwYBBQUHMAKGQmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0MjAxMV8yMDEx
// SIG // XzAzXzIyLmNydDCBnwYDVR0gBIGXMIGUMIGRBgkrBgEE
// SIG // AYI3LgMwgYMwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cu
// SIG // bWljcm9zb2Z0LmNvbS9wa2lvcHMvZG9jcy9wcmltYXJ5
// SIG // Y3BzLmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBwAG8AbABpAGMAeQBfAHMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAZ/KGpZjg
// SIG // VHkaLtPYdGcimwuWEeFjkplCln3SeQyQwWVfLiw++MNy
// SIG // 0W2D/r4/6ArKO79HqaPzadtjvyI1pZddZYSQfYtGUFXY
// SIG // DJJ80hpLHPM8QotS0LD9a+M+By4pm+Y9G6XUtR13lDni
// SIG // 6WTJRD14eiPzE32mkHSDjfTLJgJGKsKKELukqQUMm+1o
// SIG // +mgulaAqPyprWEljHwlpblqYluSD9MCP80Yr3vw70L01
// SIG // 724lruWvJ+3Q3fMOr5kol5hNDj0L8giJ1h/DMhji8MUt
// SIG // zluetEk5CsYKwsatruWy2dsViFFFWDgycScaf7H0J/je
// SIG // LDogaZiyWYlobm+nt3TDQAUGpgEqKD6CPxNNZgvAs031
// SIG // 4Y9/HG8VfUWnduVAKmWjw11SYobDHWM2l4bf2vP48hah
// SIG // mifhzaWX0O5dY0HjWwechz4GdwbRBrF1HxS+YWG18NzG
// SIG // GwS+30HHDiju3mUv7Jf2oVyW2ADWoUa9WfOXpQlLSBCZ
// SIG // gB/QACnFsZulP0V3HjXG0qKin3p6IvpIlR+r+0cjgPWe
// SIG // +L9rt0uX4ut1eBrs6jeZeRhL/9azI2h15q/6/IvrC4Dq
// SIG // aTuv/DDtBEyO3991bWORPdGdVk5Pv4BXIqF4ETIheu9B
// SIG // CrE/+6jMpF3BoYibV3FWTkhFwELJm3ZbCoBIa/15n8G9
// SIG // bW1qyVJzEw16UM0xghn2MIIZ8gIBATCBlTB+MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
// SIG // Q29kZSBTaWduaW5nIFBDQSAyMDExAhMzAAADBpycXSXj
// SIG // EKpHAAAAAAMGMA0GCWCGSAFlAwQCAQUAoIGuMBkGCSqG
// SIG // SIb3DQEJAzEMBgorBgEEAYI3AgEEMBwGCisGAQQBgjcC
// SIG // AQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEi
// SIG // BCD3omjKU+2ltBtHmjuFe7vjmLFCFgQ9lehLg9Wo3349
// SIG // uDBCBgorBgEEAYI3AgEMMTQwMqAUgBIATQBpAGMAcgBv
// SIG // AHMAbwBmAHShGoAYaHR0cDovL3d3dy5taWNyb3NvZnQu
// SIG // Y29tMA0GCSqGSIb3DQEBAQUABIIBgDLYnFx8KMIw981U
// SIG // QpNZ9shjr5dWSo/QObqSR5dO6OQKWFTjIEIy1cXATllB
// SIG // RIcURvouefPUd1cmhT80y61R5qDy2oSBBqg5ofbwpOeB
// SIG // Y6zbBy/qXgAkaYX2CTl4Zu5fubKh2n/qCUEjg3bBP/jp
// SIG // AjSyGFl3JqRSZ1yXWPGN/lHU0dvDm0JoFwvJ/vlpF0Mu
// SIG // 2DmRZJv/HrJUP7IAfViB1cxnaIrhiISF4UMEQmkvtKOR
// SIG // nyktCKYWsdJFx57q+hJZWK9sLKklj67+Gs+aeNfYc4Wy
// SIG // iGRU5lbP0+2PnNSWC1Y9gf4c1pkvorYRoCgA9f0pk6p7
// SIG // wzrlL5WajbxxQThVWznx3AEZxpTAEF0BtrmqERRS7u6P
// SIG // IredYVmK1EFYjqLSxNr45ywTIQci7jutKyYlRQ6+W1DU
// SIG // Lla09j3hUDqwAGwXiYWsGeJe3ufO4e8ji3diuULS7D3M
// SIG // bbQAMn8xtoo+DR+3NEfeeXNit1t+Priye7I4eKmmpY15
// SIG // HQOS3fqUq5WOdKGCFwAwghb8BgorBgEEAYI3AwMBMYIW
// SIG // 7DCCFugGCSqGSIb3DQEHAqCCFtkwghbVAgEDMQ8wDQYJ
// SIG // YIZIAWUDBAIBBQAwggFRBgsqhkiG9w0BCRABBKCCAUAE
// SIG // ggE8MIIBOAIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
// SIG // AwQCAQUABCDdINPV9SbmXMlZjJ0iictOWUnrhJhJebkb
// SIG // U+FEfzqfWQIGZIr4V6s8GBMyMDIzMDYxOTEwNDUxNy4z
// SIG // MzZaMASAAgH0oIHQpIHNMIHKMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBP
// SIG // cGVyYXRpb25zMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVT
// SIG // TjpERDhDLUUzMzctMkZBRTElMCMGA1UEAxMcTWljcm9z
// SIG // b2Z0IFRpbWUtU3RhbXAgU2VydmljZaCCEVcwggcMMIIE
// SIG // 9KADAgECAhMzAAABxQPNzSGh9O85AAEAAAHFMA0GCSqG
// SIG // SIb3DQEBCwUAMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAk
// SIG // BgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
// SIG // MDEwMB4XDTIyMTEwNDE5MDEzMloXDTI0MDIwMjE5MDEz
// SIG // MlowgcoxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
// SIG // aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
// SIG // ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsT
// SIG // HE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJjAk
// SIG // BgNVBAsTHVRoYWxlcyBUU1MgRVNOOkREOEMtRTMzNy0y
// SIG // RkFFMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBTZXJ2aWNlMIICIjANBgkqhkiG9w0BAQEFAAOCAg8A
// SIG // MIICCgKCAgEAq0hds70eX23J7pappaKXRhz+TT7JJ3Ov
// SIG // Vf3+N8fNpxRs5jY4hEv3BV/w5EWXbZdO4m3xj01lTI/x
// SIG // Dkq+ytjuiPe8xGXsZxDntv7L1EzMd5jISqJ+eYu8kgV0
// SIG // 56mqs8dBo55xZPPPcxf5u19zn04aMQF5PXV/C4ZLSjFa
// SIG // 9IFNcribdOm3lGW1rQRFa2jUsup6gv634q5UwH09WGGu
// SIG // 0z89RbtbyM55vmBgWV8ed6bZCZrcoYIjML8FRTvGlznq
// SIG // m6HtwZdXMwKHT3a/kLUSPiGAsrIgEzz7NpBpeOsgs9Tr
// SIG // wyWTZBNbBwyIACmQ34j+uR4et2hZk+NH49KhEJyYD2+d
// SIG // OIaDGB2EUNFSYcy1MkgtZt1eRqBB0m+YPYz7HjocPykK
// SIG // YNQZ7Tv+zglOffCiax1jOb0u6IYC5X1Jr8AwTcsaDyu3
// SIG // qAhx8cFQN9DDgiVZw+URFZ8oyoDk6sIV1nx5zZLy+hNt
// SIG // akePX9S7Y8n1qWfAjoXPE6K0/dbTw87EOJL/BlJGcKoF
// SIG // Tytr0zPg/MNJSb6f2a/wDkXoGCGWJiQrGTxjOP+R96/n
// SIG // IIG05eE1Lpky2FOdYMPB4DhW7tBdZautepTTuShmgn+G
// SIG // KER8AoA1gSSk1EC5ZX4cppVngJpblMBu8r/tChfHVdXv
// SIG // iY6hDShHwQCmZqZebgSYHnHl4urE+4K6ZC8CAwEAAaOC
// SIG // ATYwggEyMB0GA1UdDgQWBBRU6rs4v1mxNYG/rtpLwrVw
// SIG // ek0FazAfBgNVHSMEGDAWgBSfpxVdAF5iXYP05dJlpxtT
// SIG // NRnpcjBfBgNVHR8EWDBWMFSgUqBQhk5odHRwOi8vd3d3
// SIG // Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNyb3Nv
// SIG // ZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5j
// SIG // cmwwbAYIKwYBBQUHAQEEYDBeMFwGCCsGAQUFBzAChlBo
// SIG // dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2Nl
// SIG // cnRzL01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0El
// SIG // MjAyMDEwKDEpLmNydDAMBgNVHRMBAf8EAjAAMBMGA1Ud
// SIG // JQQMMAoGCCsGAQUFBwMIMA0GCSqGSIb3DQEBCwUAA4IC
// SIG // AQCMqN58frMHOScciK+Cdnr6dK8fTsgQDeZ9bvQjCuxN
// SIG // IJZJ92+xpeKRCf3Xq47qdRykkKUnZC6dHhLwt1fhwyiy
// SIG // /LfdVQ9yf1hYZ/RpTS+z0hnaoK+P/IDAiUNm32NXLhDB
// SIG // u0P4Sb/uCV4jOuNUcmJhppBQgQVhFx/57JYk1LCdjIee
// SIG // //GrcfbkQtiYob9Oa93DSjbsD1jqaicEnkclUN/mEm9Z
// SIG // snCnA1+/OQDp/8Q4cPfH94LM4J6X0NtNBeVywvWH0wuM
// SIG // aOJzHgDLCeJUkFE9HE8sBDVedmj6zPJAI+7ozLjYqw7i
// SIG // 4RFbiStfWZSGjwt+lLJQZRWUCcT3aHYvTo1YWDZskohW
// SIG // g77w9fF2QbiO9DfnqoZ7QozHi7RiPpbjgkJMAhrhpeTf
// SIG // /at2e9+HYkKObUmgPArH1Wjivwm1d7PYWsarL7u5qZuk
// SIG // 36Gb1mETS1oA2XX3+C3rgtzRohP89qZVf79lVvjmg34N
// SIG // tICK/pMk99SButghtipFSMQdbXUnS2oeLt9cKuv1MJu+
// SIG // gJ83qXTNkQ2QqhxtNRvbE9QqmqJQw5VW/4SZze1pPXxy
// SIG // OTO5yDq+iRIUubqeQzmUcCkiyNuCLHWh8OLCI5mIOC1i
// SIG // LtVDf2lw9eWropwu5SDJtT/ZwqIU1qb2U+NjkNcj1hbO
// SIG // DBRELaTTWd91RJiUI9ncJkGg/jCCB3EwggVZoAMCAQIC
// SIG // EzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZIhvcNAQEL
// SIG // BQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
// SIG // aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
// SIG // ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMT
// SIG // KU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhv
// SIG // cml0eSAyMDEwMB4XDTIxMDkzMDE4MjIyNVoXDTMwMDkz
// SIG // MDE4MzIyNVowfDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
// SIG // Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
// SIG // BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQG
// SIG // A1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIw
// SIG // MTAwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoIC
// SIG // AQDk4aZM57RyIQt5osvXJHm9DtWC0/3unAcH0qlsTnXI
// SIG // yjVX9gF/bErg4r25PhdgM/9cT8dm95VTcVrifkpa/rg2
// SIG // Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsHFPPFdvWG
// SIG // UNzBRMhxXFExN6AKOG6N7dcP2CZTfDlhAnrEqv1yaa8d
// SIG // q6z2Nr41JmTamDu6GnszrYBbfowQHJ1S/rboYiXcag/P
// SIG // XfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBpDco2LXCO
// SIG // Mcg1KL3jtIckw+DJj361VI/c+gVVmG1oO5pGve2krnop
// SIG // N6zL64NF50ZuyjLVwIYwXE8s4mKyzbnijYjklqwBSru+
// SIG // cakXW2dg3viSkR4dPf0gz3N9QZpGdc3EXzTdEonW/aUg
// SIG // fX782Z5F37ZyL9t9X4C626p+Nuw2TPYrbqgSUei/BQOj
// SIG // 0XOmTTd0lBw0gg/wEPK3Rxjtp+iZfD9M269ewvPV2HM9
// SIG // Q07BMzlMjgK8QmguEOqEUUbi0b1qGFphAXPKZ6Je1yh2
// SIG // AuIzGHLXpyDwwvoSCtdjbwzJNmSLW6CmgyFdXzB0kZSU
// SIG // 2LlQ+QuJYfM2BjUYhEfb3BvR/bLUHMVr9lxSUV0S2yW6
// SIG // r1AFemzFER1y7435UsSFF5PAPBXbGjfHCBUYP3irRbb1
// SIG // Hode2o+eFnJpxq57t7c+auIurQIDAQABo4IB3TCCAdkw
// SIG // EgYJKwYBBAGCNxUBBAUCAwEAATAjBgkrBgEEAYI3FQIE
// SIG // FgQUKqdS/mTEmr6CkTxGNSnPEP8vBO4wHQYDVR0OBBYE
// SIG // FJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1UdIARVMFMw
// SIG // UQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYBBQUHAgEWM2h0
// SIG // dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvRG9j
// SIG // cy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAKBggrBgEF
// SIG // BQcDCDAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTAL
// SIG // BgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNV
// SIG // HSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvXzpoYxDBWBgNV
// SIG // HR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1pY3Jvc29m
// SIG // dC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJB
// SIG // dXRfMjAxMC0wNi0yMy5jcmwwWgYIKwYBBQUHAQEETjBM
// SIG // MEoGCCsGAQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29m
// SIG // dC5jb20vcGtpL2NlcnRzL01pY1Jvb0NlckF1dF8yMDEw
// SIG // LTA2LTIzLmNydDANBgkqhkiG9w0BAQsFAAOCAgEAnVV9
// SIG // /Cqt4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4sQaTlz0x
// SIG // M7U518JxNj/aZGx80HU5bbsPMeTCj/ts0aGUGCLu6WZn
// SIG // OlNN3Zi6th542DYunKmCVgADsAW+iehp4LoJ7nvfam++
// SIG // Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f8449xvNo
// SIG // 32X2pFaq95W2KFUn0CS9QKC/GbYSEhFdPSfgQJY4rPf5
// SIG // KYnDvBewVIVCs/wMnosZiefwC2qBwoEZQhlSdYo2wh3D
// SIG // YXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDSPeZKPmY7
// SIG // T7uG+jIa2Zb0j/aRAfbOxnT99kxybxCrdTDFNLB62FD+
// SIG // CljdQDzHVG2dY3RILLFORy3BFARxv2T5JL5zbcqOCb2z
// SIG // AVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxnGSgkujhLmm77
// SIG // IVRrakURR6nxt67I6IleT53S0Ex2tVdUCbFpAUR+fKFh
// SIG // bHP+CrvsQWY9af3LwUFJfn6Tvsv4O+S3Fb+0zj6lMVGE
// SIG // vL8CwYKiexcdFYmNcP7ntdAoGokLjzbaukz5m/8K6TT4
// SIG // JDVnK+ANuOaMmdbhIurwJ0I9JZTmdHRbatGePu1+oDEz
// SIG // fbzL6Xu/OHBE0ZDxyKs6ijoIYn/ZcGNTTY3ugm2lBRDB
// SIG // cQZqELQdVTNYs6FwZvKhggLOMIICNwIBATCB+KGB0KSB
// SIG // zTCByjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMc
// SIG // TWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEmMCQG
// SIG // A1UECxMdVGhhbGVzIFRTUyBFU046REQ4Qy1FMzM3LTJG
// SIG // QUUxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFNlcnZpY2WiIwoBATAHBgUrDgMCGgMVACEAGvYXZJK7
// SIG // cUo62+LvEYQEx7/noIGDMIGApH4wfDELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUt
// SIG // U3RhbXAgUENBIDIwMTAwDQYJKoZIhvcNAQEFBQACBQDo
// SIG // OhN6MCIYDzIwMjMwNjE5MDczNjI2WhgPMjAyMzA2MjAw
// SIG // NzM2MjZaMHcwPQYKKwYBBAGEWQoEATEvMC0wCgIFAOg6
// SIG // E3oCAQAwCgIBAAICEhgCAf8wBwIBAAICEawwCgIFAOg7
// SIG // ZPoCAQAwNgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYBBAGE
// SIG // WQoDAqAKMAgCAQACAwehIKEKMAgCAQACAwGGoDANBgkq
// SIG // hkiG9w0BAQUFAAOBgQC9lt5Gw4S+klk2PsnSlJ6KcAR+
// SIG // ClQz5FCetpT/yClbuelcwRb4v8ClDROVKQtnq+z3QBtA
// SIG // oidB0UeHxUhPtw4/kMCkP/6eDHrlQkZjAy4xALTioa8k
// SIG // Lxjf1tcjCcOsRPxWz1vBk9jvKt5WjHUQe3LlqvIX7eWv
// SIG // u0qnz3T0qCv/yjGCBA0wggQJAgEBMIGTMHwxCzAJBgNV
// SIG // BAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
// SIG // VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
// SIG // Q29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBU
// SIG // aW1lLVN0YW1wIFBDQSAyMDEwAhMzAAABxQPNzSGh9O85
// SIG // AAEAAAHFMA0GCWCGSAFlAwQCAQUAoIIBSjAaBgkqhkiG
// SIG // 9w0BCQMxDQYLKoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkE
// SIG // MSIEIDwdooP0yoXwgbdUefnNGJYFTUXdP3JZlgj8saPA
// SIG // PNB2MIH6BgsqhkiG9w0BCRACLzGB6jCB5zCB5DCBvQQg
// SIG // GQGxkfYkd0wK+V09wO0sO+sm8gAMyj5EuKPqvNQ/fLEw
// SIG // gZgwgYCkfjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
// SIG // V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
// SIG // A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYD
// SIG // VQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAx
// SIG // MAITMwAAAcUDzc0hofTvOQABAAABxTAiBCANpceqOb9F
// SIG // jc3g6JhtzRLjq96cGBL6Y7mMUdZBMDDKgTANBgkqhkiG
// SIG // 9w0BAQsFAASCAgB4Vi8dGXAzf6L3O95yoFXI5M5vOs+X
// SIG // Sip7dqEPEU/hT7i59v7QzwseS3vJo0TZeRrdhBh6qk/E
// SIG // begL6yugWCHR7MctewsJIjAT4fIHZoNEXxhnlZX/ntVV
// SIG // 5/IHvx4LjpgjLXYbWSQnm38L2bNg99VB3/OPgs/eXdC8
// SIG // Q6arcTHWzRfn5u/k7O7cvqGv278FYKtAadkR1GzPKG3U
// SIG // ZlVa1/G/qgmpRCBlS6hlwT4yMUrQZKhAR8FGuhEeoY6H
// SIG // bE+F/VlQg1QxPk2kvf6BmUXuqGEQUsWaINR3H8Dgo3KY
// SIG // x3pUZbwjYAHNeGLO2b70zh5w9csk74lGIbrU+ja2Z2g5
// SIG // Oe91dL+UxV4MicrWPvMyMZb0t76mr2HetTu1Dk5Pkmb6
// SIG // Zt+QbkqVOHcOLEDyzdCVFDmM6xTIbzWq2oHDgsS++45J
// SIG // OeGAozvR4tdRByHJXFg7U7M6KFBr2Ve/5wDesG/cUupV
// SIG // Y7oo3yTRHQVtTo7G4EqQU7aovjuYOAeIXppNKlMvCx37
// SIG // QvXp+TF/Vvo568fWsfpZ0yi4K91ZISDHLJsJZ6NqHuiD
// SIG // DxubaR13hbRBTSPvpGVx46Gqw6AnAqrL17iw7SN+caJZ
// SIG // KHLCB21xid4/RLsn2IqtSOM1oz6lfow4ALRHX30IfgLr
// SIG // WABvrjeJoPAeBc4fPhPQA077T0i4BoFLvbuC1w==
// SIG // End signature block
